@@ -1073,10 +1073,8 @@ int main_vcfcall(int argc, char *argv[])
             case  9 : args.n_threads = strtol(optarg, 0, 0); break;
             case  8 : args.record_cmd_line = 0; break;
             case  4 :
-                if ( !strcasecmp(optarg,"0") ) args.regions_overlap = 0;
-                else if ( !strcasecmp(optarg,"1") ) args.regions_overlap = 1;
-                else if ( !strcasecmp(optarg,"2") ) args.regions_overlap = 2;
-                else error("Could not parse: --regions-overlap %s\n",optarg);
+                args.regions_overlap = parse_overlap_option(optarg);
+                if ( args.regions_overlap < 0 ) error("Could not parse: --regions-overlap %s\n",optarg);
                 break;
             default: usage(&args);
         }
